@@ -1,4 +1,5 @@
 /* 
+ * Copyright (c) 2017-2018, SyLabs, Inc. All rights reserved.
  * Copyright (c) 2017, SingularityWare, LLC. All rights reserved.
  *
  * Copyright (c) 2015-2017, Gregory M. Kurtzer. All rights reserved.
@@ -50,21 +51,17 @@ int _singularity_runtime_mount_kernelfs(void) {
     if ( singularity_config_get_bool(MOUNT_PROC) > 0 ) {
         if ( is_dir(joinpath(container_dir, "/proc")) == 0 ) {
             if ( singularity_registry_get("PIDNS_ENABLED") == NULL ) {
-                singularity_priv_escalate();
                 singularity_message(VERBOSE, "Bind-mounting host /proc\n");
                 if ( singularity_mount("/proc", joinpath(container_dir, "/proc"), NULL, MS_BIND | MS_NOSUID | MS_REC, NULL) < 0 ) {
                     singularity_message(ERROR, "Could not bind-mount host /proc into container: %s\n", strerror(errno));
                     ABORT(255);
                 }
-                singularity_priv_drop();
             } else {
-                singularity_priv_escalate();
                 singularity_message(VERBOSE, "Mounting new procfs\n");
                 if ( singularity_mount("proc", joinpath(container_dir, "/proc"), "proc", MS_NOSUID, NULL) < 0 ) {
                     singularity_message(ERROR, "Could not mount new procfs into container: %s\n", strerror(errno));
                     ABORT(255);
                 }
-                singularity_priv_drop();
             }
         } else {
             singularity_message(WARNING, "Not mounting /proc, container has no bind directory\n");
@@ -79,21 +76,17 @@ int _singularity_runtime_mount_kernelfs(void) {
     if ( singularity_config_get_bool(MOUNT_SYS) > 0 ) {
         if ( is_dir(joinpath(container_dir, "/sys")) == 0 ) {
             if ( singularity_priv_userns_enabled() == 1 ) {
-                singularity_priv_escalate();
                 singularity_message(VERBOSE, "Mounting /sys\n");
                 if ( singularity_mount("/sys", joinpath(container_dir, "/sys"), NULL, MS_BIND | MS_NOSUID | MS_REC, NULL) < 0 ) {
                     singularity_message(ERROR, "Could not mount /sys into container: %s\n", strerror(errno));
                     ABORT(255);
                 }
-                singularity_priv_drop();
             } else {
-                singularity_priv_escalate();
                 singularity_message(VERBOSE, "Mounting /sys\n");
                 if ( singularity_mount("sysfs", joinpath(container_dir, "/sys"), "sysfs", MS_NOSUID, NULL) < 0 ) {
                     singularity_message(ERROR, "Could not mount /sys into container: %s\n", strerror(errno));
                     ABORT(255);
                 }
-                singularity_priv_drop();
             }
         } else {
             singularity_message(WARNING, "Not mounting /sys, container has no bind directory\n");
